@@ -1,9 +1,9 @@
 """Set of general type helper functions"""
 from collections import defaultdict
-from typing import Any
+from typing import Any, List
 
 
-def group_by_key(list_dicts: list, key: Any) -> defaultdict:
+def group_by_key(list_dicts: List[dict], key: Any) -> defaultdict:
     """Groups list of dictionaries by key.
 
     >>> c = [{"a": 1, "b": "Wednesday"}, {"a": (1, 2, 3), "b": 16.5}]
